@@ -10,12 +10,13 @@ from distutils.core import setup
 from src.About import __version__ as v
 version = v
 
-build = "797"
+build = "822"
 
 sh = ['scribo']
 desktop_file = ['scribo.desktop']
-pixmaps = glob.glob('data/*.png')+ glob.glob('data/*.ico')+glob.glob('data/ru/*.png')+glob.glob('data/en/*.png')
-srcs = glob.glob('src/*.py')+glob.glob('src/*.qm') 
+pixmaps = glob.glob('data/*.png')+ glob.glob('data/*.ico')
+pixmapen = glob.glob('data/en/*.png')
+srcs = glob.glob('src/*.py')+glob.glob('src/*.qm')+glob.glob('src/*.ts')  
 uisrcs =  glob.glob('src/ui/*.py') 
 bugsrcs =  glob.glob('src/bugz/*.py') 
 ldmsrcs = glob.glob('src/ldm/*.py') 
@@ -45,6 +46,7 @@ data_files = [
   ('/opt/scribo/src/ldm', ldmsrcs),
   ('/opt/scribo/src/services', servsrcs),
   ('/opt/scribo/data', pixmaps),
+  ('/opt/scribo/data/en', pixmapen),
   ('/usr/share/dbus-1/services', inst_dbus),
   ('/usr/share/icons/hicolor/26x26/hildon/', inst_icon),
   ('/usr/share/icons/hicolor/scalable/hildon/', inst_icon_sca),
