@@ -43,7 +43,7 @@
         <translation type="obsolete">Отправка</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="422"/>
+        <location filename="AddPost.py" line="423"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
@@ -63,7 +63,7 @@
         <translation type="obsolete">Пост изменен</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="236"/>
+        <location filename="AddPost.py" line="237"/>
         <source>Add picture</source>
         <translation type="unfinished">Добавить рисунок</translation>
     </message>
@@ -73,12 +73,12 @@
         <translation type="obsolete">Добавить ссылку на рисунок</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="404"/>
+        <location filename="AddPost.py" line="405"/>
         <source>Add</source>
         <translation type="unfinished">Добавить</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="265"/>
+        <location filename="AddPost.py" line="266"/>
         <source>Add link</source>
         <translation type="unfinished">Добавить ссылку</translation>
     </message>
@@ -93,52 +93,52 @@
         <translation type="obsolete">Добавить html теги</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="306"/>
+        <location filename="AddPost.py" line="307"/>
         <source>Bold</source>
         <translation type="unfinished">Жирный</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="308"/>
+        <location filename="AddPost.py" line="309"/>
         <source>Italic</source>
         <translation type="unfinished">Курсив</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="310"/>
+        <location filename="AddPost.py" line="311"/>
         <source>Center</source>
         <translation type="unfinished">По центру</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="312"/>
+        <location filename="AddPost.py" line="313"/>
         <source>Right</source>
         <translation type="unfinished">По правому краю</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="314"/>
+        <location filename="AddPost.py" line="315"/>
         <source>Left</source>
         <translation type="unfinished">По левому краю</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="316"/>
+        <location filename="AddPost.py" line="317"/>
         <source>Justify</source>
         <translation type="unfinished">По ширине</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="318"/>
+        <location filename="AddPost.py" line="319"/>
         <source>Color</source>
         <translation type="unfinished">Цвет</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="360"/>
+        <location filename="AddPost.py" line="361"/>
         <source>Color text</source>
         <translation type="unfinished">Цветной текст</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="363"/>
+        <location filename="AddPost.py" line="364"/>
         <source>Choose color</source>
         <translation type="unfinished">Выбрать цвет</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="391"/>
+        <location filename="AddPost.py" line="392"/>
         <source>Add option</source>
         <translation type="unfinished">Добавить опцию</translation>
     </message>
@@ -168,12 +168,12 @@
         <translation type="obsolete">Вы хотите отправить пост с пустым заголовком?</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="220"/>
+        <location filename="AddPost.py" line="221"/>
         <source>Post is edit</source>
         <translation type="unfinished">Пост редактирован</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="303"/>
+        <location filename="AddPost.py" line="304"/>
         <source>Add html tags</source>
         <translation type="unfinished">Добавить html теги</translation>
     </message>
@@ -183,75 +183,100 @@
         <translation type="unfinished">Тема</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="107"/>
+        <location filename="AddPost.py" line="115"/>
         <source>../data/en/image.png</source>
-        <translation type="unfinished">../data/ru/image_ru.png</translation>
+        <translation type="unfinished">../data/en/image.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="114"/>
+        <location filename="AddPost.py" line="122"/>
         <source>../data/en/add_link.png</source>
-        <translation type="unfinished">../data/ru/add_link_ru.png</translation>
+        <translation type="unfinished">../data/en/add_link.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="120"/>
+        <location filename="AddPost.py" line="128"/>
         <source>../data/en/add_html.png</source>
         <translation type="unfinished">../data/en/add_html.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="126"/>
+        <location filename="AddPost.py" line="134"/>
         <source>../data/en/options.png</source>
-        <translation type="unfinished">../data/ru/options_ru.png</translation>
+        <translation type="unfinished">../data/en/options.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="135"/>
+        <location filename="AddPost.py" line="144"/>
         <source>../data/en/post_send_to.png</source>
-        <translation type="unfinished">../data/ru/post_send_to_ru.png</translation>
+        <translation type="unfinished">../data/en/post_send_to.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="139"/>
-        <source>../data/en/post_send.png</source>
-        <translation type="unfinished">../data/ru/post_send_ru.png</translation>
+        <location filename="AddPost.py" line="149"/>
+        <source>../data/en/send_post.png</source>
+        <translation type="unfinished">../data/en/send_post.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="193"/>
+        <location filename="AddPost.py" line="194"/>
         <source>The post is empty!</source>
         <translation type="unfinished">Пост - пустой!!</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="200"/>
+        <location filename="AddPost.py" line="201"/>
         <source>Do you want to send post with empty subject?</source>
         <translation type="unfinished">Вы действительно хотите послать пост без темы?</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="237"/>
+        <location filename="AddPost.py" line="238"/>
         <source>Link to the image (URL)</source>
         <translation type="unfinished">Ссылка на изображение(URL)</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="269"/>
+        <location filename="AddPost.py" line="270"/>
         <source>Link</source>
         <translation type="unfinished">Ссылка</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="401"/>
+        <location filename="AddPost.py" line="402"/>
         <source>Tags (comma separated)</source>
         <translation type="unfinished">Теги (через запятую)</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="424"/>
+        <location filename="AddPost.py" line="425"/>
         <source>Post will be lost! Continue? </source>
         <translation type="unfinished">Пост будет утерян! Продолжить?</translation>
     </message>
+    <message>
+        <location filename="AddPost.py" line="116"/>
+        <source>Add image</source>
+        <translation type="unfinished">Изображение</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="127"/>
+        <source>HTML</source>
+        <translation type="unfinished">HTML</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="133"/>
+        <source>Options</source>
+        <translation type="unfinished">Опции</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="143"/>
+        <source>Send to..</source>
+        <translation type="unfinished">Отправить в ..</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="148"/>
+        <source>Send</source>
+        <translation type="unfinished">Отправить</translation>
+    </message>
 </context>
 <context>
     <name>AddProfileWindow</name>
     <message>
-        <location filename="AddProfile.py" line="48"/>
+        <location filename="AddProfile.py" line="49"/>
         <source>Login</source>
         <translation type="unfinished">Логин</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="50"/>
+        <location filename="AddProfile.py" line="51"/>
         <source>Password</source>
         <translation type="unfinished">Пароль</translation>
     </message>
@@ -271,12 +296,12 @@
         <translation type="obsolete">Да</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="242"/>
+        <location filename="AddProfile.py" line="239"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="181"/>
+        <location filename="AddProfile.py" line="180"/>
         <source>Please, fill all fields!</source>
         <translation type="unfinished">Пожалуйста, заполните все поля!</translation>
     </message>
@@ -286,34 +311,49 @@
         <translation type="obsolete">Вы действительно хотите удалить аккаунт?</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="243"/>
+        <location filename="AddProfile.py" line="240"/>
         <source>Account was deleted</source>
         <translation type="unfinished">Аккаунт удален</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="228"/>
+        <location filename="AddProfile.py" line="225"/>
         <source>Do you really want to delete account?</source>
         <translation type="unfinished">Вы действительно хотите удалить аккаунт?</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="63"/>
+        <location filename="AddProfile.py" line="64"/>
         <source>Blog Service</source>
         <translation type="unfinished">Блог сервис</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="112"/>
+        <location filename="AddProfile.py" line="110"/>
         <source>../data/en/remove_profile.png</source>
-        <translation type="unfinished">../data/ru/remove_profile_ru.png</translation>
+        <translation type="unfinished">../data/en/remove_profile.png</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="115"/>
+        <location filename="AddProfile.py" line="113"/>
         <source>../data/en/change_profile_ok.png</source>
-        <translation type="unfinished">../data/ru/change_profile_ok_ru.png</translation>
+        <translation type="unfinished">../data/en/change_profile_ok_en.png</translation>
+    </message>
+    <message>
+        <location filename="AddProfile.py" line="116"/>
+        <source>../data/en/add_profile.png</source>
+        <translation type="unfinished">../data/en/add_profile.png</translation>
+    </message>
+    <message>
+        <location filename="AddProfile.py" line="109"/>
+        <source>Delete account</source>
+        <translation type="unfinished">Удалить аккаунт</translation>
+    </message>
+    <message>
+        <location filename="AddProfile.py" line="114"/>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
     </message>
     <message>
         <location filename="AddProfile.py" line="117"/>
-        <source>../data/en/add_profile.png</source>
-        <translation type="unfinished">../data/ru/add_profile_ru.png</translation>
+        <source>Add profile</source>
+        <translation type="unfinished">Добавить аккаунт</translation>
     </message>
 </context>
 <context>
@@ -404,12 +444,20 @@
         <translation type="unfinished">../data/en/friends_posts.png</translation>
     </message>
 </context>
+<context>
+    <name>ListFriendsPosts</name>
+    <message>
+        <location filename="ListFriendsPosts.py" line="39"/>
+        <source>Refresh</source>
+        <translation type="unfinished">Обновить</translation>
+    </message>
+</context>
 <context>
     <name>ListMyPosts</name>
     <message>
-        <location filename="ListMyPosts.py" line="61"/>
+        <location filename="ListMyPosts.py" line="124"/>
         <source>Refresh</source>
-        <translation type="obsolete">Обновить</translation>
+        <translation type="unfinished">Обновить</translation>
     </message>
     <message>
         <location filename="ListMyPosts.py" line="63"/>
@@ -437,17 +485,17 @@
         <translation type="obsolete">Удалить</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="175"/>
+        <location filename="ListMyPosts.py" line="174"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="155"/>
+        <location filename="ListMyPosts.py" line="154"/>
         <source>Do you really want to delete post?</source>
         <translation type="unfinished">Вы действительно хотите удалить пост?</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="176"/>
+        <location filename="ListMyPosts.py" line="175"/>
         <source>Please, choose messages to delete!</source>
         <translation type="unfinished">Пожалуйста, выберите удаляемые сообщения</translation>
     </message>
@@ -457,7 +505,7 @@
         <translation type="obsolete">Подождите ...</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="189"/>
+        <location filename="ListMyPosts.py" line="188"/>
         <source>Cancel</source>
         <translation type="unfinished">Отмена</translation>
     </message>
@@ -477,24 +525,29 @@
         <translation type="unfinished">Нажмите &quot;Обновить&quot; для обновления постов</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="188"/>
+        <location filename="ListMyPosts.py" line="187"/>
         <source>Operation is in progress.</source>
         <translation type="unfinished">Операция выполняется</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="190"/>
+        <location filename="ListMyPosts.py" line="189"/>
         <source>Receiving data...</source>
         <translation type="unfinished">Получение данных..</translation>
     </message>
     <message>
         <location filename="ListMyPosts.py" line="125"/>
         <source>../data/en/refresh.png</source>
-        <translation type="unfinished">../data/ru/refresh_ru.png</translation>
+        <translation type="unfinished">../data/en/refresh.png</translation>
     </message>
     <message>
         <location filename="ListMyPosts.py" line="131"/>
         <source>../data/en/post_delete.png</source>
-        <translation type="unfinished">../data/ru/post_delete_ru.png</translation>
+        <translation type="unfinished">../data/en/post_delete.png</translation>
+    </message>
+    <message>
+        <location filename="ListMyPosts.py" line="130"/>
+        <source>Delete</source>
+        <translation type="unfinished">Удалить</translation>
     </message>
 </context>
 <context>
@@ -579,17 +632,17 @@
 <context>
     <name>MyModel</name>
     <message>
-        <location filename="TreeMessage.py" line="117"/>
+        <location filename="TreeMessage.py" line="114"/>
         <source>Author</source>
         <translation type="unfinished">Автор</translation>
     </message>
     <message>
-        <location filename="TreeMessage.py" line="118"/>
+        <location filename="TreeMessage.py" line="115"/>
         <source>Date</source>
         <translation type="unfinished">Дата</translation>
     </message>
     <message>
-        <location filename="TreeMessage.py" line="119"/>
+        <location filename="TreeMessage.py" line="116"/>
         <source>Title</source>
         <translation type="unfinished">Заголовок</translation>
     </message>
@@ -607,32 +660,32 @@
         <translation type="obsolete">Отправить</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="67"/>
+        <location filename="RepeatPost.py" line="72"/>
         <source>Service</source>
         <translation type="unfinished">Сервис</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="68"/>
+        <location filename="RepeatPost.py" line="73"/>
         <source>Login</source>
         <translation type="unfinished">Логин</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="171"/>
+        <location filename="RepeatPost.py" line="185"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="144"/>
+        <location filename="RepeatPost.py" line="149"/>
         <source>Please, choose subitem for sending</source>
         <translation type="unfinished">Пожалуйста, выберите подпункт для отправки</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="165"/>
+        <location filename="RepeatPost.py" line="170"/>
         <source>Please, choose accounts or groups for sending</source>
         <translation type="unfinished">Пожалуйста, выберите аккаунты или группы для отправки</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="172"/>
+        <location filename="RepeatPost.py" line="177"/>
         <source>Post was sent</source>
         <translation type="unfinished">Пост отправлен</translation>
     </message>
@@ -644,18 +697,28 @@
     <message>
         <location filename="RepeatPost.py" line="60"/>
         <source>../data/en/send_post.png</source>
-        <translation type="unfinished">../data/ru/send_post_ru.png</translation>
+        <translation type="unfinished">../data/en/send_post.png</translation>
+    </message>
+    <message>
+        <location filename="RepeatPost.py" line="61"/>
+        <source>Send</source>
+        <translation type="unfinished">Отправить</translation>
+    </message>
+    <message>
+        <location filename="RepeatPost.py" line="187"/>
+        <source>Post will be lost! Continue? </source>
+        <translation type="unfinished">Пост будет утерян! Продолжить?</translation>
     </message>
 </context>
 <context>
     <name>StartPage</name>
     <message>
-        <location filename="StartPage.py" line="42"/>
+        <location filename="StartPage.py" line="43"/>
         <source>Login</source>
         <translation type="unfinished">Логин</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="44"/>
+        <location filename="StartPage.py" line="45"/>
         <source>Password</source>
         <translation type="unfinished">Пароль</translation>
     </message>
@@ -665,17 +728,17 @@
         <translation type="obsolete">Сервис</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="59"/>
+        <location filename="StartPage.py" line="60"/>
         <source>Go</source>
         <translation type="unfinished">Зайти</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="100"/>
+        <location filename="StartPage.py" line="101"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="101"/>
+        <location filename="StartPage.py" line="102"/>
         <source>Please, fill all fields!</source>
         <translation type="unfinished">Пожалуйста, заполните все поля!</translation>
     </message>
@@ -685,17 +748,17 @@
         <translation type="obsolete">Добро пожаловать в Scribo!</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="164"/>
+        <location filename="StartPage.py" line="158"/>
         <source>../data/Scribo.png</source>
         <translation type="unfinished">../data/Scribo.png</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="46"/>
+        <location filename="StartPage.py" line="47"/>
         <source>Blog service</source>
         <translation type="unfinished">Блог сервис</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="162"/>
+        <location filename="StartPage.py" line="156"/>
         <source>&lt;i&gt;Welcome to Scribo,&lt;br/&gt; mobile multiblog client!&lt;/i&gt;</source>
         <translation type="unfinished">&lt;i&gt;Добро пожаловать в Скрибо,&lt;br/&gt;мобильный мультиблоговый&lt;br/&gt; клиент!&lt;/i&gt;</translation>
     </message>
@@ -722,6 +785,16 @@
         <source>../data/en/home.png</source>
         <translation type="obsolete">../data/ru/home_ru.png</translation>
     </message>
+    <message>
+        <location filename="ToolbarWindow.py" line="49"/>
+        <source>Back</source>
+        <translation type="unfinished">Назад</translation>
+    </message>
+    <message>
+        <location filename="ToolbarWindow.py" line="55"/>
+        <source>Home</source>
+        <translation type="unfinished">Домой</translation>
+    </message>
 </context>
 <context>
     <name>TreeMessage</name>
@@ -733,13 +806,18 @@
     <message>
         <location filename="TreeMessage.py" line="76"/>
         <source>../data/en/refresh.png</source>
-        <translation type="unfinished">../data/ru/refresh_ru.png</translation>
+        <translation type="unfinished">../data/en/refresh.png</translation>
+    </message>
+    <message>
+        <location filename="TreeMessage.py" line="75"/>
+        <source>Refresh</source>
+        <translation type="unfinished">Обновить</translation>
     </message>
 </context>
 <context>
     <name>ViewMessage</name>
     <message>
-        <location filename="ViewMessage.py" line="103"/>
+        <location filename="ViewMessage.py" line="110"/>
         <source>no subject</source>
         <translation type="unfinished">без темы</translation>
     </message>
@@ -771,17 +849,17 @@
     <message>
         <location filename="ViewMessage.py" line="196"/>
         <source>&amp;Previous</source>
-        <translation type="obsolete">Предыдущее</translation>
+        <translation type="obsolete">Пред.</translation>
     </message>
     <message>
         <location filename="ViewMessage.py" line="202"/>
         <source>&amp;Next</source>
-        <translation type="obsolete">Следующее</translation>
+        <translation type="obsolete">След.</translation>
     </message>
     <message>
         <location filename="ViewMessage.py" line="215"/>
         <source>&amp;Edit</source>
-        <translation type="obsolete">Редактировать</translation>
+        <translation type="obsolete">Изменить</translation>
     </message>
     <message>
         <location filename="ViewMessage.py" line="221"/>
@@ -816,37 +894,52 @@
                     &lt;/b&gt;&lt;br /&gt;&lt;/div&gt;</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="232"/>
+        <location filename="ViewMessage.py" line="239"/>
         <source>&amp;Tree comments</source>
         <translation type="unfinished">&amp;Дерево комментариев</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="209"/>
+        <location filename="ViewMessage.py" line="216"/>
         <source>../data/en/post_prev.png</source>
-        <translation type="unfinished">../data/ru/post_prev_ru.png</translation>
+        <translation type="unfinished">../data/en/post_prev.png</translation>
+    </message>
+    <message>
+        <location filename="ViewMessage.py" line="222"/>
+        <source>../data/en/post_next.png</source>
+        <translation type="unfinished">../data/en/post_next.png</translation>
+    </message>
+    <message>
+        <location filename="ViewMessage.py" line="235"/>
+        <source>../data/en/post_edit.png</source>
+        <translation type="unfinished">../data/en/post_edit.png</translation>
     </message>
     <message>
         <location filename="ViewMessage.py" line="215"/>
-        <source>../data/en/post_next.png</source>
-        <translation type="unfinished">../data/ru/post_next_ru.png</translation>
+        <source>Previous</source>
+        <translation type="unfinished">Пред.</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="228"/>
-        <source>../data/en/post_edit.png</source>
-        <translation type="unfinished">../data/ru/post_edit_ru.png</translation>
+        <location filename="ViewMessage.py" line="221"/>
+        <source>Next</source>
+        <translation type="unfinished">След.</translation>
+    </message>
+    <message>
+        <location filename="ViewMessage.py" line="234"/>
+        <source>Edit</source>
+        <translation type="unfinished">Изменить</translation>
     </message>
 </context>
 <context>
     <name>main_window</name>
     <message>
-        <location filename="ToolbarWindow.py" line="29"/>
+        <location filename="ToolbarWindow.py" line="50"/>
         <source>../data/en/back.png</source>
-        <translation type="unfinished">../data/ru/back_ru.png</translation>
+        <translation type="unfinished">../data/en/back.png</translation>
     </message>
     <message>
-        <location filename="ToolbarWindow.py" line="35"/>
+        <location filename="ToolbarWindow.py" line="56"/>
         <source>../data/en/home.png</source>
-        <translation type="unfinished">../data/ru/home_ru.png</translation>
+        <translation type="unfinished">../data/en/home.png</translation>
     </message>
 </context>
 </TS>
