@@ -17,7 +17,7 @@ from services.Dispatcher import dispatcher
 
 from ToolbarWindow import ToolbarWindow
 from StartPage import StartPage
-
+from MainWindow import main_window
 __author__ = "Diana Zaiceva <zaiceva@cs.karelia.ru>"
 __version__ = "$Revision: 0.1 $"
 __date__ = "$Date: 2009/12/11 $"
@@ -25,7 +25,7 @@ __copyright__ = ""
 __license__ = "GPLv2"
 
 
-class AddProfileWindow(ToolbarWindow, StartPage):
+class AddProfileWindow(StartPage):
     """
     class for draw profile window
     @version  1.0
@@ -39,6 +39,7 @@ class AddProfileWindow(ToolbarWindow, StartPage):
         @return
         """
         QtGui.QWidget.__init__(self, parent.centralWidget())
+        #StartPage.__init__(self, main_window)
         self.accounts2 = []
         self.default = default
         self.create_actions()
@@ -89,7 +90,7 @@ class AddProfileWindow(ToolbarWindow, StartPage):
         create profile for "add profile" window
         @return
         """
-        file_tool_bar = super(AddProfileWindow, self).create_toolbar()
+        file_tool_bar = ToolbarWindow(parent=main_window.centralWidget())
         if self.default:
             file_tool_bar.addAction(self.del_act)
         file_tool_bar.addAction(self.add_acc)
@@ -101,22 +102,20 @@ class AddProfileWindow(ToolbarWindow, StartPage):
         @return
         """
         self.add_acc = QtGui.QAction(self)
-        #self.add_acc.setStatusTip(self.tr("Add profile"))
-        
         self.connect(self.add_acc, QtCore.SIGNAL("triggered()"),
                      self.add_account)
-
         if self.default:
             self.del_act = QtGui.QAction(self)
-            #self.del_act.setStatusTip(self.tr("Delete account"))
+            self.del_act.setText(self.tr("Delete account"))
             self.del_act.setIcon(QtGui.QIcon(self.tr("../data/en/remove_profile.png")))
             self.connect(self.del_act, QtCore.SIGNAL("triggered()"),
                          self.del_account_ui)
             self.add_acc.setIcon(QtGui.QIcon(self.tr("../data/en/change_profile_ok.png")))
+            self.add_acc.setText(self.tr("OK"))
         else:
             self.add_acc.setIcon(QtGui.QIcon(self.tr("../data/en/add_profile.png")))
+            self.add_acc.setText(self.tr("Add profile"))
 
-        super(AddProfileWindow, self).create_actions()
 
 
     def create_list_acc(self, default):
@@ -194,15 +193,15 @@ class AddProfileWindow(ToolbarWindow, StartPage):
 
     def _edit_account(self):
 
-        acc = type(self.default)()
 
-        acc.username = str(self.login_edit.text())
-        acc.passwd = str(self.pasw_edit.text())
+        old_pass = self.default.passwd
+
+        self.default.passwd = str(self.pasw_edit.text())
 
         try:
-            acc.check_login()
+            self.default.check_login()
         except WarningExc, exc:
-            acc.del_account()
+            self.default.passwd = old_pass
             main_window.show_warning(exc)
             return False
 
@@ -211,9 +210,7 @@ class AddProfileWindow(ToolbarWindow, StartPage):
         except WarningExc, exc:
             main_window.show_warning(exc)
 
-        self.default.passwd = str(self.pasw_edit.text())
         self.default.set_default()
-        acc.del_account()
 
         return True
 
@@ -245,8 +242,8 @@ class AddProfileWindow(ToolbarWindow, StartPage):
 
         else:
             #all accounts are deleted
-            del_acc.del_account()
+            main_prof.remove_account(del_acc)
         main_window.home_window()
 
 
-from MainWindow import *
+#from MainWindow import *
