@@ -22,7 +22,7 @@ __date__ = "$Date: 2010/01/06 $"
 __copyright__ = ""
 __license__ = "GPLv2"
 
-class TreeMessage(ToolbarWindow):
+class TreeMessage(QtGui.QWidget):
     """
     class for draw tree of comments window
     @version  1.0
@@ -61,7 +61,7 @@ class TreeMessage(ToolbarWindow):
         create profile for "add profile" window
         @return
         """
-        file_tool_bar = super(TreeMessage, self).create_toolbar()
+        file_tool_bar = ToolbarWindow(parent=main_window.centralWidget())
         file_tool_bar.addAction(self.refresh_act)
         return file_tool_bar
 
@@ -72,14 +72,11 @@ class TreeMessage(ToolbarWindow):
         """
 
         self.refresh_act = QtGui.QAction(self)
-        #self.refresh_act.setStatusTip(self.tr("Refresh"))
+        self.refresh_act.setText(self.tr("Refresh"))
         self.refresh_act.setIcon(QtGui.QIcon(self.tr("../data/en/refresh.png")))
         self.connect(self.refresh_act, QtCore.SIGNAL("triggered()"),
                      self.reload_window)
 
-        super(TreeMessage, self).create_actions()
-
-
     def view_message(self):
         """  
         view choosing message
