@@ -27,7 +27,7 @@ __date__ = "$Date: 2010/01/06 $"
 __copyright__ = ""
 __license__ = "GPLv2"
 
-class ViewMessage(ToolbarWindow):
+class ViewMessage(QtGui.QWidget):
     """
     class for drawing window viewing post or comments
     @version  1.0
@@ -56,6 +56,13 @@ class ViewMessage(ToolbarWindow):
         #check out JS scripts
         QWebSettings.globalSettings().setAttribute(QWebSettings.JavascriptEnabled,
                                                    False)
+        #cache settings
+        #QWebSettings.globalSettings().setAttribute(QWebSettings.LocalStorageEnabled,
+        #                                           True)
+        #connect plugins for video
+        QWebSettings.globalSettings().setAttribute(QWebSettings.PluginsEnabled,
+                                                   True)
+
         #proxy settings
         from ConfigDriver import config
         sett = config.get('Main', 'proxy')
@@ -133,7 +140,7 @@ class ViewMessage(ToolbarWindow):
         """
         self.view_mes_widget.setHtml('<head><meta http-equiv="Content-Type" \
                     content="text/html; charset=utf-8" /> '
-                    + css + '</head><body>'
+                    + css + '</head><body style=\"-moz-user-select: none; -khtml-user-select: none; user-select: none;\">'
                     + '<h3><div class="title">%s</div></h3>' % (title)
                     + '<br/><div class="author">%s</div>' % (author)
                     + '<div class="date">%s</div>' % (date)
@@ -176,7 +183,7 @@ class ViewMessage(ToolbarWindow):
         create profile for "add profile" window
         @return
         """
-        file_tool_bar = super(ViewMessage, self).create_toolbar()
+        file_tool_bar = ToolbarWindow(parent=main_window.centralWidget())
         file_tool_bar.addAction(self.edit_act)
         if not self.msg.is_editable():
             self.edit_act.setDisabled(True)
@@ -187,7 +194,7 @@ class ViewMessage(ToolbarWindow):
         create profile for "add profile" window
         @return
         """
-        second_tool_bar = super(ViewMessage, self).create_toolbar_second()
+        second_tool_bar = ToolbarWindow(parent=main_window.centralWidget(), right=True)
         second_tool_bar.addAction(self.up_act)
         second_tool_bar.addAction(self.down_act)
         return second_tool_bar
@@ -205,13 +212,13 @@ class ViewMessage(ToolbarWindow):
                      self.refresh_mes)
         """
         self.up_act = QtGui.QAction(self)
-        #self.up_act.setStatusTip(self.tr("Previous message"))
+        self.up_act.setText(self.tr("Previous"))
         self.up_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_prev.png")))
         self.connect(self.up_act, QtCore.SIGNAL("triggered()"),
                      self.view_prev_message)
 
         self.down_act = QtGui.QAction(self)
-        #self.down_act.setStatusTip(self.tr("Next message"))
+        self.down_act.setText(self.tr("Next"))
         self.down_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_next.png")))
         self.connect(self.down_act, QtCore.SIGNAL("triggered()"),
                      self.view_next_message)
@@ -224,18 +231,17 @@ class ViewMessage(ToolbarWindow):
                      self.write_comment)
         """
         self.edit_act = QtGui.QAction(self)
-        #self.edit_act.setStatusTip(self.tr("Edit"))
+        self.edit_act.setText(self.tr("Edit"))
         self.edit_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_edit.png")))
         self.connect(self.edit_act, QtCore.SIGNAL("triggered()"),
                      self.edit_post)
 
         self.tree_act = QtGui.QAction(self.tr("&Tree comments"), self)
-        #self.tree_act.setStatusTip(self.tr("Tree of comments"))
+        #self.tree_act.setText(self.tr("Tree of comments"))
         #self.tree_act.setIcon(QtGui.QIcon("../data/tree.png"))
         self.connect(self.tree_act, QtCore.SIGNAL("triggered()"),
                      self.tree_comments)
 
-        super(ViewMessage, self).create_actions()
 
     def view_prev_message(self):
         """
